@@ -20,7 +20,7 @@ import logging
 logger = logging.Logger(__name__)
 
 
-def copy_default_profile_collection(tmp_path, *, copy_yaml=True):
+def copy_default_profile_collection(tmp_path, *, copy_py=True, copy_yaml=True):
     """
     Copy default profile collections (only .py files) to temporary directory.
     Returns the new temporary directory.
@@ -33,7 +33,9 @@ def copy_default_profile_collection(tmp_path, *, copy_yaml=True):
     os.makedirs(new_pc_path, exist_ok=True)
 
     # Copy simulated profile collection (only .py files)
-    patterns = ["*.py", "*.ipy"]
+    patterns = []
+    if copy_py:
+        patterns.extend(["*.py", "*.ipy"])
     if copy_yaml:
         patterns.append("*.yaml")
     for pattern in patterns:
@@ -276,6 +278,32 @@ def wait_for_condition(time, condition):
     return False
 
 
+def wait_for_task_result(time, task_uid):
+    """
+    Wait for the results of the task defined by ``task_uid``. Raises ``TimeoutError`` if
+    timeout ``time`` is exceeded while waiting for the task result. Returns the task result
+    of the task only if it was completed.
+    """
+    dt = 0.2  # Period for checking if the task is available
+    time_stop = ttime.time() + time
+    while ttime.time() < time_stop:
+        ttime.sleep(dt / 2)
+        try:
+            resp, _ = zmq_secure_request("task_result", params={"task_uid": task_uid})
+
+            assert resp["success"] is True, f"Request for task result failed: {resp['msg']}"
+            assert resp["task_uid"] == task_uid
+
+            if resp["status"] == "completed":
+                return resp["result"]
+
+        except TimeoutError:
+            pass
+        ttime.sleep(dt / 2)
+
+    raise TimeoutError(f"Timeout occurred while waiting for results of the task {task_uid!r}")
+
+
 def clear_redis_pool():
     # Remove all Redis entries.
     pq = PlanQueueOperations()
@@ -283,6 +311,7 @@ def clear_redis_pool():
     async def run():
         await pq.start()
         await pq.delete_pool_entries()
+        await pq.user_group_permissions_clear()
 
     asyncio.run(run())
 
@@ -342,11 +371,11 @@ sources:
 
 
 class ReManager:
-    def __init__(self, params=None, *, stdout=subprocess.DEVNULL, stderr=subprocess.DEVNULL):
+    def __init__(self, params=None, *, stdout=sys.stdout, stderr=sys.stdout):
         self._p = None
-        self._start_manager(params, stdout=stdout, stderr=stderr)
+        self.start_manager(params, stdout=stdout, stderr=stderr)
 
-    def _start_manager(self, params=None, *, stdout=subprocess.DEVNULL, stderr=subprocess.DEVNULL):
+    def start_manager(self, params=None, *, stdout=sys.stdout, stderr=sys.stdout, cleanup=True):
         """
         Start RE manager.
 
@@ -358,14 +387,25 @@ class ReManager:
             Device to forward stdout, ``None`` - print to console
         stderr
             Device to forward stdout, ``None`` - print to console
+        cleanup: boolean
+            Perform cleanup (remove related Redis keys) before opening the manager.
 
         Returns
         -------
         subprocess.Popen
             Subprocess in which the manager is running. It needs to be stopped at certain point.
         """
+        params = params or []
+
+        # Set logging level for RE Manager unless it is already set in parameters
+        #   Leads to excessive output and some tests may fail at tearup. Enable only when needed.
+        logging_levels = ("--verbose", "--quiet", "--silent")
+        if not any([_ in params for _ in logging_levels]):
+            params.append("--verbose")
+
         if not self._p:
-            clear_redis_pool()
+            if cleanup:
+                clear_redis_pool()
 
             cmd = ["start-re-manager"]
             if params:
@@ -386,46 +426,83 @@ class ReManager:
         except subprocess.TimeoutExpired:
             return False
 
-    def stop_manager(self, timeout=10):
+    def stop_manager(self, timeout=10, cleanup=True):
         """
         Attempt to exit the subprocess that is running manager in orderly way and kill it
         after timeout.
 
         Parameters
         ----------
-        p: subprocess.Popen
-            Subprocess in which the manager is running
         timeout: float
             Timeout in seconds.
+        cleanup: boolean
+            Perform cleanup (remove created Redis keys) after closing the manager.
         """
         if self._p:
             try:
                 # If the process is already terminated, then don't attempt to communicate with it.
                 if self._p.poll() is None:
+                    success, msg = False, ""
+
                     # Try to stop the manager in a nice way first by sending the command
-                    resp, err_msg = zmq_secure_request(method="manager_stop", params=None)
-                    assert resp, str(err_msg)
-                    assert resp["success"] is True, f"Request to stop the manager failed: {resp['msg']}."
+                    resp1, err_msg1 = zmq_secure_request(method="manager_stop", params=None)
+                    assert resp1, str(err_msg1)
+                    success = resp1["success"]
 
-                    self._p.wait(timeout)
+                    if not success:
+                        # If the command was rejected, try 'safe_off' mode that kills the RE worker environment
+                        msg += f"Request to stop the manager in with the 'safe_on' option failed: {resp1['msg']}."
+                        resp2, err_msg2 = zmq_secure_request(method="manager_stop", params={"option": "safe_off"})
+                        assert resp2, str(err_msg2)
+                        success = resp2["success"]
+                        if not success:
+                            msg += (
+                                " Request to stop the manager in with the 'safe_off' "
+                                f"option failed: {resp2['msg']}."
+                            )
+                        else:
+                            msg += " Attempting to stop the manager using 'safe_off' option"
 
-                clear_redis_pool()
+                    # If both requests failed, then there is nothing to wait
+                    if not success:
+                        raise RuntimeError(msg)
+
+                    # If only the first request failed, then there is a chance that the manager stops
+                    try:
+                        self._p.communicate(timeout=timeout)
+                        self._p = None
+                    except subprocess.TimeoutExpired:
+                        raise RuntimeError(f"Timeout occured while waiting for the manager to stop: {msg}")
+
+                    # If at least one of the requests failed and there is an error message, then fail the test
+                    if msg:
+                        raise RuntimeError(msg)
 
             except Exception as ex:
                 # The manager is not responsive, so just kill the process.
-                self._p.kill()
-                clear_redis_pool()
+                if self._p:
+                    self._p.kill()
+                    self._p.wait(timeout)
                 assert False, f"RE Manager failed to stop: {str(ex)}"
 
-            self._p = None
+            finally:
+                if cleanup:
+                    clear_redis_pool()
+                self._p = None
 
-    def kill_manager(self):
+    def kill_manager(self, timeout=10):
         """
         Kill the subprocess running RE Manager. Use only to stop RE Manager that failed to start correctly.
         The operation will always succeed.
+
+        Parameters
+        ----------
+        timeout: float
+            Timeout in seconds.
         """
         if self._p:
             self._p.kill()
+            self._p.wait(timeout)
             clear_redis_pool()
 
 
@@ -449,7 +526,7 @@ def re_manager_cmd():
     re = {"re": None}
     failed_to_start = False
 
-    def _create(params, *, stdout=subprocess.DEVNULL, stderr=subprocess.DEVNULL):
+    def _create(params, *, stdout, stderr):
         """
         Create RE Manager. ``start-re-manager`` is called with command line parameters from
           the list ``params``.
@@ -475,7 +552,7 @@ def re_manager_cmd():
             else:
                 re["re"].kill_manager()
 
-    def create_re_manager(params=None, *, stdout=subprocess.DEVNULL, stderr=subprocess.DEVNULL):
+    def create_re_manager(params=None, *, stdout=sys.stdout, stderr=sys.stdout):
         params = params or []
         _close()
         _create(params, stdout=stdout, stderr=stderr)
